# Generated by Django 2.0 on 2017-12-11 03:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0025_auto_20171211_0342'),
    ]

    operations = [
        migrations.AlterField(
            model_name='show',
            name='ttl',
            field=models.PositiveIntegerField(default=60, help_text='Time to live; minutes until cached feed refreshed', verbose_name='TTL'),
        ),
    ]
