# Generated by Django 2.0 on 2017-12-11 03:42

from django.db import migrations


def get_ttl(apps, schema_editor):
    Show = apps.get_model('podcast', 'Show')
    for show in Show.objects.all():
        show.ttl = 60
        show.save(update_fields=['ttl'])


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0024_show_ttl'),
    ]

    operations = [
        migrations.RunPython(get_ttl, reverse_code=migrations.RunPython.noop),
    ]
