# Generated by Django 2.0 on 2017-12-11 04:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0026_auto_20171211_0342'),
    ]

    operations = [
        migrations.AddField(
            model_name='show',
            name='managing_editor',
            field=models.EmailField(default='', help_text='E-mail of administrative contact', max_length=255, verbose_name='editor e-mail'),
        ),
        migrations.AddField(
            model_name='show',
            name='webmaster',
            field=models.EmailField(blank=True, help_text='E-mail of technical contact; if blank, uses editor e-mail', max_length=255, verbose_name='webmaster e-mail'),
        ),
        migrations.AlterField(
            model_name='show',
            name='author_email',
            field=models.EmailField(blank=True, help_text='E-mail of administrative contact; if blank, uses editor e-mail', max_length=254, verbose_name='author e-mail'),
        ),
        migrations.AlterField(
            model_name='show',
            name='author_name',
            field=models.CharField(blank=True, help_text='Name of "artist" of the podcast; if blank, uses show title', max_length=255, verbose_name='author name'),
        ),
        migrations.AlterField(
            model_name='show',
            name='owner_email',
            field=models.EmailField(blank=True, help_text='E-mail of technical contact; if blank, uses webmaster e-mail', max_length=254, verbose_name='owner e-mail'),
        ),
        migrations.AlterField(
            model_name='show',
            name='owner_name',
            field=models.CharField(blank=True, help_text='Name of technical contact; if blank, uses show title', max_length=255, verbose_name='owner name'),
        ),
    ]
