# Generated by Django 2.0 on 2017-12-11 04:24

from django.db import migrations


def get_managing_editor(apps, schema_editor):
    Show = apps.get_model('podcast', 'Show')
    for show in Show.objects.all():
        show.managing_editor = show.author_email
        show.webmaster = show.owner_email
        show.save(update_fields=['managing_editor', 'webmaster'])


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0027_auto_20171211_0424'),
    ]

    operations = [
        migrations.RunPython(get_managing_editor, reverse_code=migrations.RunPython.noop),
    ]
