# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-09 23:25
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0002_remove_episode_order'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='show',
            name='ttl',
        ),
    ]
