# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-11-21 21:25
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0021_auto_20171028_1742'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='category',
            name='json',
        ),
    ]
