# Generated by Django 2.0 on 2017-12-11 04:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0028_auto_20171211_0424'),
    ]

    operations = [
        migrations.AlterField(
            model_name='show',
            name='managing_editor',
            field=models.EmailField(help_text='E-mail of administrative contact', max_length=255, verbose_name='editor e-mail'),
        ),
    ]
